@@ -11,7 +11,7 @@ def User_Fetch(request):
         DSResponse(
             request=request,
             data=User.objects.
-                filter().
+                exclude(id=0).
                 distinct().
                 get_range_rows11(
                 request=request,
@@ -26,7 +26,7 @@ def User_FetchExclBots(request):
         DSResponse(
             request=request,
             data=User.objects.
-                exclude(props=User.props.bot).
+                exclude(props=User.props.bot, id=0).
                 distinct().
                 get_range_rows11(
                 request=request,
@@ -51,8 +51,8 @@ def User_Remove(request):
 
 
 @JsonResponseWithException()
-def  User_Lookup(request):
-    return JsonResponse(DSResponse(request=request, data= User.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
+def User_Lookup(request):
+    return JsonResponse(DSResponse(request=request, data=User.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException()
