@@ -18,6 +18,11 @@ logger = logging.getLogger(__name__)
 
 class CommonQuerySet(QuerySet):
 
+    # def filter(self, *args, **kwargs):
+    #     if self.alive_only:
+    #         setAttr(kwargs, 'deleted_at__isnull', True)
+    #     return super().filter(*args, **kwargs)
+
     def __init__(self, model=None, query=None, using=None, hints=None, alive_only=True, enabledAll=False):
         self.alive_only = alive_only
         self.enabledAll = enabledAll
@@ -499,6 +504,17 @@ class CommonQuerySet(QuerySet):
 
 
 class CommonManager(Manager):
+    @staticmethod
+    def delete_underscore_element(data):
+        if not isinstance(data, dict):
+            raise Exception('data must be dict')
+
+        res = dict()
+        for key, value in data.items():
+            if str(key).find('_', 0, 1) == -1:
+                setAttr(res, key, value)
+        return res
+
     def refresh_mat_view(self, mat_view):
         with connection.cursor() as cursor:
             logger.debug(f'Refreshing: {mat_view}')
