@@ -10,6 +10,10 @@ logger = logging.getLogger(__name__)
 
 
 class AuditQuerySet(CommonQuerySet):
+    def _check_ed_izm_qty(self, **kwargs):
+        if kwargs.get('ed_izm') != None and kwargs.get('qty') == None or kwargs.get('ed_izm') == None and kwargs.get('qty') != None:
+            raise Exception(f'ed_izm and qty not be along')
+
     def __init__(self, model=None, query=None, using=None, hints=None, alive_only=True):
         self.alive_only = alive_only
         super().__init__(model=model, query=query, using=using, hints=hints, alive_only=alive_only)
@@ -111,6 +115,10 @@ class AuditModel(Model):
         self.deleted_at = timezone.now()
         self.save()
 
+    def soft_restore(self):
+        self.deleted_at = None
+        self.save()
+
     objects = AuditManager()
     all_objects = AuditManager(alive_only=False)
 
