@@ -1,13 +1,10 @@
-import datetime
 import logging
 
 from django.db.models import TextField
 from django.forms import model_to_dict
-from django.utils import timezone
 
 from isc_common import setAttr
 from isc_common.auth.models.user import User
-from isc_common.datetime import StrToDate
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditModel, AuditQuerySet, AuditManager
@@ -19,23 +16,26 @@ class ParamsQuerySet(AuditQuerySet):
     def get_params(self, request, *args):
         request = DSRequest(request=request)
         data = request.get_data()
-        app_id = data.get('app_id')
+        if data.get('user_id') == None:
+            return []
 
-        periodEraseHistory = int(super().get_or_create(user=request.user, key=f'periodEraseHistory{app_id}', defaults=dict(value=1))[0].value)
+        # app_id = data.get('app_id')
 
-        lastEraseHistory = super().get_or_create(user=request.user, key=f'lastEraseHistory{app_id}', defaults=dict(value=timezone.now()))[0].value
-        lastEraseHistory = StrToDate(lastEraseHistory, '%Y-%m-%d %H:%M:%S')
-        delta = timezone.now() - lastEraseHistory
-
-        if not delta or delta.days > periodEraseHistory:
-            super().filter(user=request.user, key__icontains='_ComboBoxItemSS').delete()
-            if not lastEraseHistory:
-                super().create(user=request.user, key=f'lastEraseHistory{app_id}', value=datetime.datetime.now())
-            else:
-                super().filter(user=request.user, key=f'lastEraseHistory{app_id}', value=lastEraseHistory).update(value=timezone.now())
+        # periodEraseHistory = int(super().get_or_create(user=request.user, key=f'periodEraseHistory{app_id}', defaults=dict(value=1))[0].value)
+        #
+        # lastEraseHistory = super().get_or_create(user=request.user, key=f'lastEraseHistory{app_id}', defaults=dict(value=timezone.now()))[0].value
+        # lastEraseHistory = StrToDate(lastEraseHistory, '%Y-%m-%d %H:%M:%S')
+        # delta = timezone.now() - lastEraseHistory
+        #
+        # if not delta or delta.days > periodEraseHistory:
+        #     super().filter(user=request.user, key__icontains='_ComboBoxItemSS').delete()
+        #     if not lastEraseHistory:
+        #         super().create(user=request.user, key=f'lastEraseHistory{app_id}', value=datetime.datetime.now())
+        #     else:
+        #         super().filter(user=request.user, key=f'lastEraseHistory{app_id}', value=lastEraseHistory).update(value=timezone.now())
 
         queryResult = super().filter(user_id=data.get('user_id'))
-        res = [model_to_dict(record) for record in queryResult]
+        res = [ParamsManager.getRecord1(record) for record in queryResult]
         return res
 
     def get_params_key(self, request, *args):
@@ -63,6 +63,15 @@ class ParamsManager(AuditManager):
         }
         return res
 
+    @staticmethod
+    def getRecord1(record):
+        res = {
+            'id': record.id,
+            'key': record.key[1:len(record.key) - 1] if record.key[0:1] == "'" else record.key,
+            'value': record.value,
+        }
+        return res
+
     def deleteFromRequest(self, request):
         request = DSRequest(request=request)
         data = request.get_data()
@@ -106,7 +115,7 @@ class ParamsManager(AuditManager):
 class Params(AuditModel):
     user = ForeignKeyCascade(User)
     key = TextField()
-    value = TextField(null=True, blank=True)
+    value = TextField()
 
     objects = ParamsManager()
 
