@@ -8,14 +8,7 @@ logger = logging.getLogger(__name__)
 
 
 class Messages_importanceQuerySet(BaseRefQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class Messages_importanceManager(BaseRefManager):
